summaryrefslogtreecommitdiffstats
path: root/net/http/http_transaction.h
diff options
context:
space:
mode:
authorrtenneti@chromium.org <rtenneti@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-01-25 00:54:41 +0000
committerrtenneti@chromium.org <rtenneti@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-01-25 00:54:41 +0000
commit662626649fb422d8c1d33cf76774364e9307516a (patch)
tree77970f022220e196a294e60e5346e95c833506e5 /net/http/http_transaction.h
parent8a3a964a9f9c9e662597f62b293011e0943600b8 (diff)
downloadchromium_src-662626649fb422d8c1d33cf76774364e9307516a.zip
chromium_src-662626649fb422d8c1d33cf76774364e9307516a.tar.gz
chromium_src-662626649fb422d8c1d33cf76774364e9307516a.tar.bz2
Renamed disk_cache_based_ssl_host_info.* to
disk_cache_based_quic_server_info.*. Renamed ssl_host_info.* to quic_server_info.*. Deleted all SSLConfig and CertVerifier related code. Replaced them with QuicCryptoClientConfig::CachedState. Will fill out the details in quic_server_info (persist/restore code) in the next CL. R=wtc@chromium.org Review URL: https://codereview.chromium.org/140823019 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@247044 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/http/http_transaction.h')
-rw-r--r--net/http/http_transaction.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/net/http/http_transaction.h b/net/http/http_transaction.h
index b532760..58ea3e0 100644
--- a/net/http/http_transaction.h
+++ b/net/http/http_transaction.h
@@ -21,8 +21,8 @@ struct HttpRequestInfo;
class HttpResponseInfo;
class IOBuffer;
struct LoadTimingInfo;
+class QuicServerInfo;
class X509Certificate;
-class SSLHostInfo;
// Represents a single HTTP transaction (i.e., a single request/response pair).
// HTTP redirects are not followed and authentication challenges are not
@@ -134,9 +134,9 @@ class NET_EXPORT_PRIVATE HttpTransaction {
// zero will be returned. This does not include the request headers.
virtual UploadProgress GetUploadProgress() const = 0;
- // SetSSLHostInfo sets a object which reads and writes public information
- // about an SSL server.
- virtual void SetSSLHostInfo(SSLHostInfo*) {};
+ // SetQuicServerInfo sets a object which reads and writes public information
+ // about a QUIC server.
+ virtual void SetQuicServerInfo(QuicServerInfo* quic_server_info) {};
// Populates all of load timing, except for request start times and receive
// headers time.